@@ -99,12 +99,12 @@ if('HASH' eq ref $tree)
 return (Data::TreeDumper::DefaultNodesToDisplay($tree)) ;
 }
 
-
 my $tree_dumper = new Data::TreeDumper::OO ;
 #~ $tree_dumper->UseAnsi(1) ;
 #~ $tree_dumper->UseAscii(0) ;
 #~ $tree_dumper->SetMaxDepth(2) ;
-
-print $tree_dumper->Dump(\%tree, "Data:TreeDumper dump example:",  DISPLAY_ROOT_ADDRESS => 1) ;
+ 
+print $tree_dumper->Dump(\%tree, "Data:TreeDumper dump example:",  DISPLAY_ROOT_ADDRESS => 1, DISPLAY_PERL_SIZE => 1, NO_WRAP => 1) ;
 
 #~ print $tree_dumper->Dump(\%tree, "Data:TreeDumper dump example:", INDENTATION => '  ', FILTER => \&Data::TreeDumper::HashKeysSorter) ;
+
